eigen_table: Generalized eigenvalues of a solved model

View source: R/solve.R

eigen_tableR Documentation

Generalized eigenvalues of a solved model

Description

Generalized eigenvalues of a solved model

Usage

eigen_table(x)

Arguments

x

A qpm_solution.

Value

A data frame with the moduli of the generalized eigenvalues of the model companion pencil, sorted ascending, with stability flags.

Examples

head(eigen_table(qpm_solve(qpm_template("bkl"))))

qpmR documentation built on Sept. 29, 2026, 5:10 p.m.