| summary.qpm_filtration | R Documentation |
Summarise a filtration
## S3 method for class 'qpm_filtration'
summary(object, ...)
object |
A |
... |
Unused. |
A data frame with, for each model variable, whether it was observed and the mean, standard deviation and range of its smoothed path, plus the mean estimation standard error for latent states.
sol <- qpm_solve(qpm_template("bkl"))
obs <- simulate(sol, nsim = 40, seed = 1, burn = 20)
summary(qpm_filter(sol, obs[, c("period", "pi", "i", "q")]))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.