| eigen_table | R Documentation |
Generalized eigenvalues of a solved model
eigen_table(x)
x |
A |
A data frame with the moduli of the generalized eigenvalues of the model companion pencil, sorted ascending, with stability flags.
head(eigen_table(qpm_solve(qpm_template("bkl"))))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.