| logLik.qpm_filtration | R Documentation |
For a qpm_filtration this is the Kalman-filter log-likelihood of
the data under the calibrated model, with zero degrees of freedom
(nothing was estimated). For a qpm_estimate it is the
log-likelihood at the posterior mode (or at the maximum for
method = "mle"), with degrees of freedom equal to the number of
estimated parameters — so stats::AIC() and stats::BIC() work.
## S3 method for class 'qpm_filtration'
logLik(object, ...)
## S3 method for class 'qpm_estimate'
logLik(object, ...)
object |
A |
... |
Unused. |
An object of class logLik.
sol <- qpm_solve(qpm_template("bkl"))
obs <- simulate(sol, nsim = 40, seed = 1, burn = 20)
fit <- qpm_filter(sol, obs[, c("period", "pi", "i", "q")])
logLik(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.