R/dsl-model.R
qpm_calibrate.Rd
Update a model's calibration
qpm_calibrate(model, ..., sigma = NULL)
A qpm_model.
qpm_model
Named parameter values to update. Every name must already exist in the model (typo protection).
Optional named vector of shock standard deviations to update.
The updated qpm_model.
m <- qpm_template("bkl") m <- qpm_calibrate(m, b2 = 0.3, c2 = 2)