| qpm_calibrate | R Documentation |
Update a model's calibration
qpm_calibrate(model, ..., sigma = NULL)
model |
A |
... |
Named parameter values to update. Every name must already exist in the model (typo protection). |
sigma |
Optional named vector of shock standard deviations to update. |
The updated qpm_model.
m <- qpm_template("bkl")
m <- qpm_calibrate(m, b2 = 0.3, c2 = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.