| summary.qpm_estimate | R Documentation |
Returns the posterior summary as a data frame — prior, mode, mean, standard deviation, credible interval, R-hat and effective sample size — so it can be used programmatically rather than only read.
## S3 method for class 'qpm_estimate'
summary(object, level = 0.9, ...)
object |
A |
level |
Credible level for the interval. |
... |
Unused. |
A data frame, one row per estimated parameter.
m <- qpm_model(variables = vars(x = "x"), shocks = shocks(e),
equations = eqs(x ~ rho * x[-1] + e),
params = list(rho = 0.5))
obs <- simulate(qpm_solve(qpm_calibrate(m, rho = 0.8)), nsim = 120, seed = 1)
est <- qpm_estimate(m, obs, priors(rho = beta(0.5, 0.2)),
iter = 300, chains = 1, seed = 2, verbose = FALSE)
summary(est)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.